==> formflow-1.0.6-py3-none-any.whl: formflow/src/pages/PrivacyPolicy.tsx <==
const PrivacyPolicy = () => {
    return (
        <>
            <h2>Privacy Policy</h2>
            <h3>1. Introduction</h3>
            <p>Welcome to FormFlow (“we,” “our,” “us”). We are committed to protecting your
            privacy and ensuring that your personal information is handled in a safe and
            responsible manner. This Privacy Policy outlines how we collect, use, and
            protect any information that you provide when you use our form service.</p>
            <h3>2. Information We Collect</h3>
            <p>When your website visitors use the form service, they may submit various types
            of information depending on the fields you have included in the form. This
            information can include, but is not limited to:</p>
            <ul>
            <li>Name</li>
            <li>Email Address</li>
            <li>Message Content</li>
            <li>Attachments (e.g., documents, images, or other files)</li>
            <li>Any other fields you have configured on your form</li>
            </ul>
            <p>Please note that the specific data collected will vary based on how you
            customize your form.</p>
            <h3>3. How We Use the Information</h3>
            <p>The information collected through the form on your website is used solely to
            send an email to the designated recipient (you). We do not store or retain any
            of the information submitted through the form. Once the email is sent, the data
            is deleted and is not stored on our servers.</p>
            <h3>4. Data Security</h3>
            <p>We take data security seriously. While the information is in our possession
            (during the email transmission process), we use industry-standard security
            measures to protect it from unauthorized access, disclosure, alteration, or
            destruction.</p>
            <h3>5. Third-Party Access</h3>
            <p>We do not share, sell, or rent your website visitors’ personal information to
            any third parties. The information is used exclusively for the purpose of
            sending you an email that contains the details submitted through the form on
            your website.</p>
            <h3>6. Your Responsibilities</h3>
            <p>As a user of our service, it is your responsibility to ensure that your website
            visitors are informed about how their data will be handled. We recommend that
            you include a link to this Privacy Policy on your website, alongside the form,
            to ensure transparency.</p>
            <h3>7. Contact Us</h3>
            <p>If you have any questions or concerns about this Privacy Policy or our
            practices, please contact us at contact@formflow.org.</p>
        </>
    );
};

export default PrivacyPolicy;

==> formflow-1.0.17-py3-none-any.whl: formflow/src/pages/PrivacyPolicy.tsx <==
const PrivacyPolicy = () => {
    return (
        <>
            <h2>Privacy Policy</h2>
            <h3>1. Introduction</h3>
            <p>Welcome to FormFlow (“we,” “our,” “us”). We are committed to protecting your
            privacy and ensuring that your personal information is handled in a safe and
            responsible manner. This Privacy Policy outlines how we collect, use, and
            protect any information that you provide when you use our form service.</p>
            <h3>2. Information We Collect</h3>
            <p>When your website visitors use the form service, they may submit various types
            of information depending on the fields you have included in the form. This
            information can include, but is not limited to:</p>
            <ul>
            <li>Name</li>
            <li>Email Address</li>
            <li>Message Content</li>
            <li>Attachments (e.g., documents, images, or other files)</li>
            <li>Any other fields you have configured on your form</li>
            </ul>
            <p>Please note that the specific data collected will vary based on how you
            customize your form.</p>
            <h3>3. How We Use the Information</h3>
            <p>The information collected through the form on your website is used solely to
            send an email to the designated recipient. We do not store or retain any
            of the information submitted through the form. Once the email is sent, the data
            is deleted and is not stored on our servers.</p>
            <h3>4. Data Security</h3>
            <p>We take data security seriously. While the information is in our possession
            (during the email transmission process), we use industry-standard security
            measures to protect it from unauthorized access, disclosure, alteration, or
            destruction.</p>
            <h3>5. Third-Party Access</h3>
            <p>We do not share, sell, or rent your website visitors’ personal information to
            any third parties. The information is used exclusively for the purpose of
            sending you an email that contains the details submitted through the form on
            your website.</p>
            <h3>6. Your Responsibilities</h3>
            <p>As a user of our service, it is your responsibility to ensure that your website
            visitors are informed about how their data will be handled. We recommend that
            you include a link to this Privacy Policy on your website, alongside the form,
            to ensure transparency.</p>
            <h3>7. Contact Us</h3>
            <p>If you have any questions or concerns about this Privacy Policy or our
            practices, please contact us at contact@formflow.org.</p>
        </>
    );
};

export default PrivacyPolicy;
